.. schemelink:

======================
Scheme Link (``link``)
======================

.. automodule:: orangecanvas.scheme.link


.. autoclass:: SchemeLink
   :members:
   :exclude-members:
      enabled_changed,
      dynamic_enabled_changed
   :member-order: bysource
   :show-inheritance:

   .. autoattribute:: enabled_changed(enabled)

   .. autoattribute:: dynamic_enabled_changed(enabled)
